Bug

Struct Bug 

pub struct Bug {
Show 49 fields pub alias: Alias, pub op_sys: String, pub classification: String, pub id: i32, pub url: String, pub creator: String, pub creator_detail: User, pub summary: String, pub status: String, pub estimated_time: Option<i64>, pub target_milestone: String, pub cc: Vec<String>, pub cc_detail: Vec<User>, pub is_open: bool, pub is_creator_accessible: bool, pub docs_contact: Option<String>, pub docs_contact_detail: Option<User>, pub assigned_to: String, pub assigned_to_detail: User, pub resolution: String, pub severity: String, pub product: String, pub platform: String, pub last_change_time: DateTime<Utc>, pub remaining_time: Option<i64>, pub priority: String, pub whiteboard: String, pub creation_time: DateTime<Utc>, pub is_confirmed: bool, pub qa_contact: String, pub qa_contact_detail: Option<User>, pub dupe_of: Option<i32>, pub target_release: Option<Version>, pub actual_time: Option<i64>, pub component: Component, pub is_cc_accessible: bool, pub version: Version, pub keywords: Vec<String>, pub depends_on: Vec<i32>, pub blocks: Vec<i32>, pub see_also: Option<Vec<String>>, pub groups: Vec<String>, pub deadline: Option<NaiveDate>, pub update_token: Option<String>, pub work_time: Option<i64>, pub flags: Option<Vec<Flag>>, pub tags: Option<Vec<String>>, pub dependent_products: Option<Vec<String>>, pub extra: Value,
}
The representation of a single Bugzilla bug with all its fields.

Fields

alias: Aliasop_sys: Stringclassification: Stringid: i32url: Stringcreator: Stringcreator_detail: Usersummary: Stringstatus: Stringestimated_time: Option<i64>target_milestone: Stringcc: Vec<String>cc_detail: Vec<User>is_open: boolis_creator_accessible: booldocs_contact: Option<String>docs_contact_detail: Option<User>assigned_to: Stringassigned_to_detail: Userresolution: Stringseverity: Stringproduct: Stringplatform: Stringlast_change_time: DateTime<Utc>remaining_time: Option<i64>priority: Stringwhiteboard: Stringcreation_time: DateTime<Utc>is_confirmed: boolqa_contact: Stringqa_contact_detail: Option<User>dupe_of: Option<i32>target_release: Option<Version>actual_time: Option<i64>component: Componentis_cc_accessible: boolversion: Versionkeywords: Vec<String>depends_on: Vec<i32>blocks: Vec<i32>see_also: Option<Vec<String>>groups: Vec<String>deadline: Option<NaiveDate>

Bugzilla stores deadline only as YYYY-MM-DD, so it can’t deserialize to full DateTime.

update_token: Option<String>work_time: Option<i64>flags: Option<Vec<Flag>>tags: Option<Vec<String>>dependent_products: Option<Vec<String>>extra: Value

Implementations

Source

impl Bug

pub fn get_flag<'a>(&'a self, name: &str) -> Option<&'a str>

Returns a the value of the flag corresponding to the flag name. If no flag by that name is set in the bug, the function returns None.

Panics

The function panics if flags are not available at all. Enable flags when accessing the Bugzilla instance.